@@ -6,7 +6,7 @@ from islatu import io
 from islatu import refl_data
 from islatu import stitching
 from islatu import __version__
-from yaml import load, dumps
+from yaml import load, dump
 try:
     from yaml import CLoader as Loader, CDumper as Dumper
 except ImportError:
@@ -233,11 +233,11 @@ def reduce(run_numbers, yaml_file, directory='/dls/{}/data/{}/{}/', metadata=met
     the_boss.metadata['data']['column 3'] = 'sigma RQz, standard deviation'
     if the_boss.output_columns == 3:
         data = np.array([refl.q, refl.R, refl.dR]).T
-        np.savetxt(the_boss.directory_path + '/processing/XRR_' + run_numbers[0] + '.dat', data, header='{}\n 1 2 3'.format(dumps(the_boss.metadata)))
+        np.savetxt(the_boss.directory_path + '/processing/XRR_' + run_numbers[0] + '.dat', data, header='{}\n 1 2 3'.format(dump(the_boss.metadata)))
     elif the_boss.output_columns == 4:
         data = np.array([refl.q, refl.R, refl.dR, refl.dq]).T
         the_boss.metadata['data']['column 4'] = 'sigma Qz / Aa^-1, standard deviation'
-        np.savetxt(the_boss.directory_path + '/processing/XRR_' + run_numbers[0] + '.dat', data, header='{}\n 1 2 3 4'.format(dumps(the_boss.metadata)))
+        np.savetxt(the_boss.directory_path + '/processing/XRR_' + run_numbers[0] + '.dat', data, header='{}\n 1 2 3 4'.format(dump(the_boss.metadata)))
     print("-" * 10)
     print('Reduced Data Stored in Processing Directory')
     print("-" * 10)
